@@ -1,6 +1,6 @@
 package Gearman::Objects;
 use version ();
-$Gearman::Objects::VERSION = version->declare("2.004.001");
+$Gearman::Objects::VERSION = version->declare("2.004.002");
 
 use strict;
 use warnings;
@@ -89,7 +89,7 @@ C<$js> a string, hash reference or array reference of aforementioned.
 Hash reference should contain at least host key.
 
 All keys: host, port (4730 on default), use_ssl, key_file, cert_file,
-ca_certs, socket_cb
+socket_cb
 
 B<return> [canonicalized list]
 
@@ -207,7 +207,7 @@ sub socket {
     my $sc = "IO::Socket::IP";
     if ($js->{use_ssl}) {
         $sc = "IO::Socket::SSL";
-        for (qw/ key_file cert_file ca_certs /) {
+        for (qw/ key_file cert_file /) {
             $js->{$_} || next;
             $opts{ join('_', "SSL", $_) } = $js->{$_};
         }
